@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+"""Salad is a schema language for describing JSON or YAML structured linked data documents"""
 
 import logging
 
