@@ -1,7 +1,16 @@
 """Generate langauge specific loaders for a particular SALAD schema."""
 import sys
-from io import open
-from typing import Any, Dict, List, MutableMapping, MutableSequence, Optional
+from io import TextIOWrapper
+from typing import (
+    Any,
+    Dict,
+    List,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    TextIO,
+    Union,
+)
 
 from . import schema
 from .codegen_base import CodeGenBase
@@ -28,7 +37,9 @@ def codegen(
     gen = None  # type: Optional[CodeGenBase]
     if lang == "python":
         if target:
-            dest = open(target, mode="w", encoding="utf-8")
+            dest: Union[TextIOWrapper, TextIO] = open(
+                target, mode="w", encoding="utf-8"
+            )
         else:
             dest = sys.stdout
         gen = PythonCodeGen(dest)
@@ -39,9 +50,7 @@ def codegen(
             examples=examples,
         )
     else:
-        raise SchemaSaladException(
-            "Unsupported code generation language '{}'".format(lang)
-        )
+        raise SchemaSaladException(f"Unsupported code generation language '{lang}'")
     assert gen is not None
 
     gen.prologue()
@@ -92,13 +101,14 @@ def codegen(
 
             for field in rec.get("fields", []):
                 if field.get("jsonldPredicate") == "@id":
+                    subscope = field.get("subscope")
                     fieldpred = field["name"]
                     optional = bool("https://w3id.org/cwl/salad#null" in field["type"])
                     uri_loader = gen.uri_loader(
                         gen.type_loader(field["type"]), True, False, None
                     )
                     gen.declare_id_field(
-                        fieldpred, uri_loader, field.get("doc"), optional
+                        fieldpred, uri_loader, field.get("doc"), optional, subscope
                     )
                     break
 
@@ -107,11 +117,16 @@ def codegen(
                 type_loader = gen.type_loader(field["type"])
                 jld = field.get("jsonldPredicate")
                 fieldpred = field["name"]
+                subscope = None
+
                 if isinstance(jld, MutableMapping):
                     ref_scope = jld.get("refScope")
-
                     if jld.get("typeDSL"):
                         type_loader = gen.typedsl_loader(type_loader, ref_scope)
+                    elif jld.get("secondaryFilesDSL"):
+                        type_loader = gen.secondaryfilesdsl_loader(type_loader)
+                    elif jld.get("subscope"):
+                        subscope = jld.get("subscope")
                     elif jld.get("_type") == "@id":
                         type_loader = gen.uri_loader(
                             type_loader, jld.get("identity", False), False, ref_scope
