@@ -40,9 +40,9 @@ def _ensure_directory_and_write(path: str, contents: str) -> None:
 def doc_to_doc_string(doc: Optional[str], indent_level: int = 0) -> str:
     lead = " " + "  " * indent_level + "* " * indent_level
     if doc:
-        doc_str = "{}<BLOCKQUOTE>\n".format(lead)
-        doc_str += "\n".join(["{}{}".format(lead, line) for line in doc.split("\n")])
-        doc_str += "{}</BLOCKQUOTE>".format(lead)
+        doc_str = f"{lead}<BLOCKQUOTE>\n"
+        doc_str += "\n".join([f"{lead}{line}" for line in doc.split("\n")])
+        doc_str += f"{lead}</BLOCKQUOTE>"
     else:
         doc_str = ""
     return doc_str
@@ -74,10 +74,10 @@ prims = {
         init="new PrimitiveLoader<Long>(Long.class)",
     ),
     "http://www.w3.org/2001/XMLSchema#float": TypeDef(
-        instance_type="Float",
-        name="FloatInstance",
-        loader_type="Loader<Float>",
-        init="new PrimitiveLoader<Float>(Float.class)",
+        instance_type="Double",
+        name="DoubleInstance",
+        loader_type="Loader<Double>",
+        init="new PrimitiveLoader<Double>(Double.class)",
     ),
     "http://www.w3.org/2001/XMLSchema#double": TypeDef(
         instance_type="Double",
@@ -110,7 +110,7 @@ class JavaCodeGen(CodeGenBase):
     def __init__(
         self, base: str, target: Optional[str], examples: Optional[str]
     ) -> None:
-        super(JavaCodeGen, self).__init__()
+        super().__init__()
         self.base_uri = base
         sp = urlsplit(base)
         self.examples = examples
@@ -171,16 +171,16 @@ class JavaCodeGen(CodeGenBase):
         self.current_loader = StringIO()
         self.current_fieldtypes = {}  # type: Dict[str, TypeDef]
         self.current_fields = StringIO()
-        interface_doc_str = "* Auto-generated interface for <I>%s</I><BR>" % classname
+        interface_doc_str = f"* Auto-generated interface for <I>{classname}</I><BR>"
         if not abstract:
             implemented_by = "This interface is implemented by {{@link {}Impl}}<BR>"
             interface_doc_str += implemented_by.format(cls)
         interface_doc_str += doc_to_doc_string(doc)
-        class_doc_str = "* Auto-generated class implementation for <I>{}</I><BR>".format(
-            classname
+        class_doc_str = (
+            f"* Auto-generated class implementation for <I>{classname}</I><BR>"
         )
         class_doc_str += doc_to_doc_string(doc)
-        with open(os.path.join(self.main_src_dir, "{}.java".format(cls)), "w") as f:
+        with open(os.path.join(self.main_src_dir, f"{cls}.java"), "w") as f:
 
             if extends:
                 ext = (
@@ -209,7 +209,7 @@ public interface {cls} {ext} {{""".format(
         if self.current_class_is_abstract:
             return
 
-        with open(os.path.join(self.main_src_dir, "{}Impl.java".format(cls)), "w") as f:
+        with open(os.path.join(self.main_src_dir, f"{cls}Impl.java"), "w") as f:
             f.write(
                 """package {package};
 
@@ -270,7 +270,7 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
     def end_class(self, classname, field_names):
         # type: (str, List[str]) -> None
         with open(
-            os.path.join(self.main_src_dir, "{}.java".format(self.current_class)), "a"
+            os.path.join(self.main_src_dir, f"{self.current_class}.java"), "a"
         ) as f:
             f.write(
                 """
@@ -300,7 +300,7 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
         self.current_loader.write("""  }""")
 
         with open(
-            os.path.join(self.main_src_dir, "{}Impl.java".format(self.current_class)),
+            os.path.join(self.main_src_dir, f"{self.current_class}Impl.java"),
             "a",
         ) as f:
             f.write(self.current_fields.getvalue())
@@ -331,24 +331,24 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
                             instance_type="java.util.Optional<{}>".format(
                                 non_null_type.instance_type
                             ),
-                            init="new OptionalLoader({})".format(non_null_type.name),
-                            name="optional_{}".format(non_null_type.name),
+                            init=f"new OptionalLoader({non_null_type.name})",
+                            name=f"optional_{non_null_type.name}",
                             loader_type="Loader<java.util.Optional<{}>>".format(
                                 non_null_type.instance_type
                             ),
                         )
                     )
                 if (
-                    type_1_name == "array_of_{}".format(type_2_name)
-                    or type_2_name == "array_of_{}".format(type_1_name)
+                    type_1_name == f"array_of_{type_2_name}"
+                    or type_2_name == f"array_of_{type_1_name}"
                 ) and USE_ONE_OR_LIST_OF_TYPES:
-                    if type_1_name == "array_of_{}".format(type_2_name):
+                    if type_1_name == f"array_of_{type_2_name}":
                         single_type = type_2
                         array_type = type_1
                     else:
                         single_type = type_1
                         array_type = type_2
-                    fqclass = "{}.{}".format(self.package, single_type.instance_type)
+                    fqclass = f"{self.package}.{single_type.instance_type}"
                     return self.declare_type(
                         TypeDef(
                             instance_type="{}.utils.OneOrListOf<{}>".format(
@@ -357,7 +357,7 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
                             init="new OneOrListOfLoader<{}>({}, {})".format(
                                 fqclass, single_type.name, array_type.name
                             ),
-                            name="one_or_array_of_{}".format(single_type.name),
+                            name=f"one_or_array_of_{single_type.name}",
                             loader_type="Loader<{}.utils.OneOrListOf<{}>>".format(
                                 self.package, fqclass
                             ),
@@ -384,8 +384,8 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
                         # special doesn't work out with subclassing, gotta be more clever
                         # instance_type="List<{}>".format(i.instance_type),
                         instance_type="java.util.List<Object>",
-                        name="array_of_{}".format(i.name),
-                        init="new ArrayLoader({})".format(i.name),
+                        name=f"array_of_{i.name}",
+                        init=f"new ArrayLoader({i.name})",
                         loader_type="Loader<java.util.List<{}>>".format(
                             i.instance_type
                         ),
@@ -406,14 +406,24 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
                         instance_type=self.safe_name(type_declaration["name"]),
                         name=self.safe_name(type_declaration["name"]),
                         init="new RecordLoader<{clazz}>({clazz}{ext}.class)".format(
-                            clazz=fqclass, ext="Impl" if not is_abstract else "",
+                            clazz=fqclass,
+                            ext="Impl" if not is_abstract else "",
                         ),
-                        loader_type="Loader<{}>".format(fqclass),
+                        loader_type=f"Loader<{fqclass}>",
                     )
                 )
             raise SchemaException("wft {}".format(type_declaration["type"]))
         if type_declaration in prims:
             return prims[type_declaration]
+        if type_declaration in ("Expression", "https://w3id.org/cwl/cwl#Expression"):
+            return self.declare_type(
+                TypeDef(
+                    name=self.safe_name(type_declaration) + "Loader",
+                    init="new ExpressionLoader()",
+                    loader_type="Loader<String>",
+                    instance_type="String",
+                )
+            )
         return self.collected_types[self.safe_name(type_declaration)]
 
     def type_loader_enum(self, type_declaration: Dict[str, Any]) -> TypeDef:
@@ -424,7 +434,7 @@ public class {cls}Impl extends SavableImpl implements {cls} {{
         symbols_decl = 'new String[] {{"{}"}}'.format(
             '", "'.join(sym for sym in symbols)
         )
-        enum_path = os.path.join(self.main_src_dir, "{}.java".format(clazz))
+        enum_path = os.path.join(self.main_src_dir, f"{clazz}.java")
         with open(enum_path, "w") as f:
             f.write(
                 """package {package};
@@ -470,13 +480,17 @@ public enum {clazz} {{
             TypeDef(
                 instance_type=clazz,
                 name=self.safe_name(type_declaration["name"]),
-                loader_type="Loader<{clazz}>".format(clazz=clazz),
-                init="new EnumLoader({clazz}.class)".format(clazz=clazz),
+                loader_type=f"Loader<{clazz}>",
+                init=f"new EnumLoader({clazz}.class)",
             )
         )
 
     def declare_field(
-        self, name: str, fieldtype: TypeDef, doc: Optional[str], optional: bool
+        self,
+        name: str,
+        fieldtype: TypeDef,
+        doc: Optional[str],
+        optional: bool,
     ) -> None:
         fieldname = name
         property_name = self.property_name(fieldname)
@@ -494,7 +508,7 @@ public enum {clazz} {{
             fieldname=fieldname, field_doc_str=doc_to_doc_string(doc, indent_level=1)
         )
         with open(
-            os.path.join(self.main_src_dir, "{}.java".format(self.current_class)), "a"
+            os.path.join(self.main_src_dir, f"{self.current_class}.java"), "a"
         ) as f:
             f.write(
                 """
@@ -574,7 +588,12 @@ public enum {clazz} {{
             )
 
     def declare_id_field(
-        self, name: str, fieldtype: TypeDef, doc: str, optional: bool
+        self,
+        name: str,
+        fieldtype: TypeDef,
+        doc: str,
+        optional: bool,
+        subscope: Optional[str],
     ) -> None:
         if self.current_class_is_abstract:
             return
@@ -602,6 +621,9 @@ public enum {clazz} {{
     }}
     __baseUri = (String) {safename};
 """
+        if subscope is not None:
+            name = name + subscope
+
         self.current_loader.write(
             set_uri.format(safename=self.safe_name(name), fieldname=shortname(name))
         )
@@ -630,7 +652,7 @@ public enum {clazz} {{
                 is_uri=True,
                 scoped_id=scoped_id,
                 ref_scope=ref_scope,
-                loader_type="Loader<{}>".format(instance_type),
+                loader_type=f"Loader<{instance_type}>",
             )
         )
 
@@ -646,7 +668,7 @@ public enum {clazz} {{
                 init='new IdMapLoader({}, "{}", "{}")'.format(
                     inner.name, map_subject, map_predicate
                 ),
-                loader_type="Loader<{}>".format(instance_type),
+                loader_type=f"Loader<{instance_type}>",
             )
         )
 
@@ -655,9 +677,9 @@ public enum {clazz} {{
         return self.declare_type(
             TypeDef(
                 instance_type=instance_type,
-                name="typedsl_{}_{}".format(inner.name, ref_scope),
-                init="new TypeDslLoader({}, {})".format(inner.name, ref_scope),
-                loader_type="Loader<{}>".format(instance_type),
+                name=f"typedsl_{inner.name}_{ref_scope}",
+                init=f"new TypeDslLoader({inner.name}, {ref_scope})",
+                loader_type=f"Loader<{instance_type}>",
             )
         )
 
@@ -692,7 +714,7 @@ public enum {clazz} {{
         def template_from_resource(resource):
             # type: (str) -> string.Template
             template_str = pkg_resources.resource_string(
-                __name__, "java/%s" % resource
+                __name__, f"java/{resource}"
             ).decode("utf-8")
             template = string.Template(template_str)
             return template
@@ -721,7 +743,8 @@ public enum {clazz} {{
             ),
         )
         expand_resource_template_to(
-            "README.md", os.path.join(self.target_dir, "README.md"),
+            "README.md",
+            os.path.join(self.target_dir, "README.md"),
         )
 
         vocab = ""
@@ -745,7 +768,7 @@ public enum {clazz} {{
             shutil.copytree(self.examples, utils_resources)
             for example_name in os.listdir(self.examples):
                 if example_name.startswith("valid"):
-                    basename = os.path.basename(example_name).split(".", 1)[0]
+                    basename = os.path.basename(example_name).rsplit(".", 1)[0]
                     example_tests += """
   @org.junit.Test
   public void test{basename}ByString() throws Exception {{
@@ -771,9 +794,10 @@ public enum {clazz} {{
     String yaml = new String(java.nio.file.Files.readAllBytes(resPath), "UTF8");
     java.util.Map<String, Object> doc;
     doc = (java.util.Map<String, Object>) YamlUtils.mapFromString(yaml);
-    RootLoader.loadDocument(doc);
+    RootLoader.loadDocument(doc, url.toString());
   }}""".format(
-                        basename=basename, example_name=example_name,
+                        basename=basename.replace("-", "_").replace(".", "_"),
+                        example_name=example_name,
                     )
 
         template_args = dict(
@@ -791,8 +815,19 @@ public enum {clazz} {{
             "test_utils": self.test_src_dir,
         }
         for (util_src, util_target) in util_src_dirs.items():
-            for util in pkg_resources.resource_listdir(__name__, "java/%s" % util_src):
+            for util in pkg_resources.resource_listdir(__name__, f"java/{util_src}"):
                 src_path = os.path.join(util_target, "utils", util)
                 src_template = template_from_resource(os.path.join(util_src, util))
                 src = src_template.safe_substitute(template_args)
                 _ensure_directory_and_write(src_path, src)
+
+    def secondaryfilesdsl_loader(self, inner: TypeDef) -> TypeDef:
+        instance_type = inner.instance_type or "Object"
+        return self.declare_type(
+            TypeDef(
+                instance_type=instance_type,
+                name=f"secondaryfilesdsl_{inner.name}",
+                init=f"new SecondaryFilesDslLoader({inner.name})",
+                loader_type=f"Loader<{instance_type}>",
+            )
+        )
