@@ -10,7 +10,6 @@ from urllib.parse import urlparse
 import pkg_resources  # part of setuptools
 from rdflib.parser import Parser
 from rdflib.plugin import register
-
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 
 from . import codegen, jsonld_context, schema
@@ -25,7 +24,10 @@ _logger = logging.getLogger("salad")
 
 
 def printrdf(
-    workflow: str, wf: Union[CommentedMap, CommentedSeq], ctx: Dict[str, Any], sr: str,
+    workflow: str,
+    wf: Union[CommentedMap, CommentedSeq],
+    ctx: Dict[str, Any],
+    sr: str,
 ) -> None:
     g = jsonld_context.makerdf(workflow, wf, ctx)
     print(g.serialize(format=sr, encoding="utf-8").decode("utf-8"))
@@ -326,7 +328,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
 
     # If no document specified, all done.
     if not args.document:
-        print("Schema `{}` is valid".format(args.schema))
+        print(f"Schema `{args.schema}` is valid")
         return 0
 
     # Load target document and resolve refs
@@ -365,7 +367,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
         )
     except ValidationException as e:
         msg2 = to_one_line_messages(e) if args.print_oneline else str(e)
-        _logger.error("While validating document `%s`:\n%s" % (args.document, msg2))
+        _logger.error(f"While validating document `{args.document}`:\n{msg2}")
         return 1
 
     # Optionally convert the document to RDF
@@ -381,7 +383,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
         print(json_dumps(doc_metadata, indent=4))
         return 0
 
-    print("Document `{}` is valid".format(args.document))
+    print(f"Document `{args.document}` is valid")
 
     return 0
 
