@@ -20,6 +20,7 @@ from urllib.request import pathname2url
 
 from ruamel import yaml
 from ruamel.yaml.comments import CommentedMap
+
 from schema_salad.exceptions import SchemaSaladException, ValidationException
 from schema_salad.fetcher import DefaultFetcher, Fetcher
 from schema_salad.sourceline import SourceLine, add_lc_filename
@@ -28,7 +29,7 @@ _vocab = {}  # type: Dict[str, str]
 _rvocab = {}  # type: Dict[str, str]
 
 
-class Savable(object):
+class Savable:
     @classmethod
     def fromDoc(cls, _doc, baseuri, loadingOptions, docRoot=None):
         # type: (Any, str, LoadingOptions, Optional[str]) -> Savable
@@ -39,7 +40,7 @@ class Savable(object):
         pass
 
 
-class LoadingOptions(object):
+class LoadingOptions:
     def __init__(
         self,
         fetcher=None,  # type: Optional[Fetcher]
@@ -67,8 +68,8 @@ class LoadingOptions(object):
 
         if fetcher is None:
             import requests
-            from cachecontrol.wrapper import CacheControl
             from cachecontrol.caches import FileCache
+            from cachecontrol.wrapper import CacheControl
 
             if "HOME" in os.environ:
                 session = CacheControl(
@@ -213,12 +214,12 @@ def expand_url(
             if url in loadingOptions.rvocab:
                 return loadingOptions.rvocab[url]
         else:
-            raise ValidationException("Term '{}' not in vocabulary".format(url))
+            raise ValidationException(f"Term '{url}' not in vocabulary")
 
     return url
 
 
-class _Loader(object):
+class _Loader:
     def load(self, doc, baseuri, loadingOptions, docRoot=None):
         # type: (Any, str, LoadingOptions, Optional[str]) -> Any
         pass
@@ -278,7 +279,7 @@ class _ArrayLoader(_Loader):
         return r
 
     def __repr__(self):  # type: () -> str
-        return "array<{}>".format(self.items)
+        return f"array<{self.items}>"
 
 
 class _EnumLoader(_Loader):
@@ -291,7 +292,57 @@ class _EnumLoader(_Loader):
         if doc in self.symbols:
             return doc
         else:
-            raise ValidationException("Expected one of {}".format(self.symbols))
+            raise ValidationException(f"Expected one of {self.symbols}")
+
+
+class _SecondaryDSLLoader(_Loader):
+    def __init__(self, inner):
+        # type: (_Loader) -> None
+        self.inner = inner
+
+    def load(self, doc, baseuri, loadingOptions, docRoot=None):
+        # type: (Any, str, LoadingOptions, Optional[str]) -> Any
+        r: List[Dict[str, Any]] = []
+        if isinstance(doc, MutableSequence):
+            for d in doc:
+                if isinstance(d, str):
+                    if d.endswith("?"):
+                        r.append({"pattern": d[:-1], "required": False})
+                    else:
+                        r.append({"pattern": d})
+                elif isinstance(d, dict):
+                    new_dict: Dict[str, Any] = {}
+                    if "pattern" in d:
+                        new_dict["pattern"] = d.pop("pattern")
+                    else:
+                        raise ValidationException(
+                            "Missing pattern in secondaryFiles specification entry: {}".format(
+                                d
+                            )
+                        )
+                    new_dict["required"] = (
+                        d.pop("required") if "required" in d else None
+                    )
+
+                    if len(d):
+                        raise ValidationException(
+                            "Unallowed values in secondaryFiles specification entry: {}".format(
+                                d
+                            )
+                        )
+
+                else:
+                    raise ValidationException(
+                        "Expected a string or sequence of (strings or mappings)."
+                    )
+        elif isinstance(doc, str):
+            if doc.endswith("?"):
+                r.append({"pattern": doc[:-1], "required": False})
+            else:
+                r.append({"pattern": doc})
+        else:
+            raise ValidationException("Expected str or sequence of str")
+        return self.inner.load(r, baseuri, loadingOptions, docRoot)
 
 
 class _RecordLoader(_Loader):
@@ -309,6 +360,17 @@ class _RecordLoader(_Loader):
         return str(self.classtype)
 
 
+class _ExpressionLoader(_Loader):
+    def __init__(self, items: Type[str]) -> None:
+        self.items = items
+
+    def load(self, doc, baseuri, loadingOptions, docRoot=None):
+        # type: (Any, str, LoadingOptions, Optional[str]) -> Any
+        if not isinstance(doc, str):
+            raise ValidationException("Expected a str")
+        return doc
+
+
 class _UnionLoader(_Loader):
     def __init__(self, alternates):
         # type: (Sequence[_Loader]) -> None
@@ -322,9 +384,7 @@ class _UnionLoader(_Loader):
                 return t.load(doc, baseuri, loadingOptions, docRoot=docRoot)
             except ValidationException as e:
                 errors.append(
-                    ValidationException(
-                        "tried {} but".format(t.__class__.__name__), None, [e]
-                    )
+                    ValidationException(f"tried {t.__class__.__name__} but", None, [e])
                 )
         raise ValidationException("", None, errors, "-")
 
@@ -343,18 +403,23 @@ class _URILoader(_Loader):
     def load(self, doc, baseuri, loadingOptions, docRoot=None):
         # type: (Any, str, LoadingOptions, Optional[str]) -> Any
         if isinstance(doc, MutableSequence):
-            doc = [
-                expand_url(
-                    i,
-                    baseuri,
-                    loadingOptions,
-                    self.scoped_id,
-                    self.vocab_term,
-                    self.scoped_ref,
-                )
-                for i in doc
-            ]
-        if isinstance(doc, str):
+            newdoc = []
+            for i in doc:
+                if isinstance(i, str):
+                    newdoc.append(
+                        expand_url(
+                            i,
+                            baseuri,
+                            loadingOptions,
+                            self.scoped_id,
+                            self.vocab_term,
+                            self.scoped_ref,
+                        )
+                    )
+                else:
+                    newdoc.append(i)
+            doc = newdoc
+        elif isinstance(doc, str):
             doc = expand_url(
                 doc,
                 baseuri,
@@ -524,9 +589,9 @@ def file_uri(path, split_frag=False):  # type: (str, bool) -> str
         urlpath = pathname2url(path)
         frag = ""
     if urlpath.startswith("//"):
-        return "file:{}{}".format(urlpath, frag)
+        return f"file:{urlpath}{frag}"
     else:
-        return "file://{}{}".format(urlpath, frag)
+        return f"file://{urlpath}{frag}"
 
 
 def prefix_url(url, namespaces):  # type: (str, Dict[str, str]) -> str
