@@ -20,9 +20,9 @@ from typing import (
 from urllib.parse import urldefrag, urlparse
 
 from pkg_resources import resource_stream
-
 from ruamel import yaml
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
+
 from schema_salad.utils import (
     CacheType,
     ResolveType,
@@ -189,7 +189,7 @@ def get_metaschema() -> Tuple[Names, List[Dict[str, str]], Loader]:
 
     if not isinstance(j2, list):
         _logger.error("%s", j2)
-        raise SchemaParseException("Not a list: {}".format(j2))
+        raise SchemaParseException(f"Not a list: {j2}")
     else:
         sch_obj = make_avro(j2, loader)
     try:
@@ -230,7 +230,8 @@ schema_type = Tuple[Loader, Union[Names, SchemaParseException], Dict[str, Any],
 
 
 def load_schema(
-    schema_ref: ResolveType, cache: Optional[CacheType] = None,
+    schema_ref: ResolveType,
+    cache: Optional[CacheType] = None,
 ) -> schema_type:
     """
     Load a schema that can be used to validate documents using load_and_validate.
@@ -374,15 +375,13 @@ def validate_doc(
                 except ClassValidationException as exc1:
                     errors = [
                         ClassValidationException(
-                            "tried `{}` but".format(name), sourceline, [exc1]
+                            f"tried `{name}` but", sourceline, [exc1]
                         )
                     ]
                     break
                 except ValidationException as exc2:
                     errors.append(
-                        ValidationException(
-                            "tried `{}` but".format(name), sourceline, [exc2]
-                        )
+                        ValidationException(f"tried `{name}` but", sourceline, [exc2])
                     )
 
             objerr = "Invalid"
@@ -405,9 +404,7 @@ def get_anon_name(
         name = rec["name"]
         if isinstance(name, str):
             return name
-        raise ValidationException(
-            "Expected name field to be a string, was {}".format(name)
-        )
+        raise ValidationException(f"Expected name field to be a string, was {name}")
     anon_name = ""
     if rec["type"] in ("enum", saladp + "enum"):
         for sym in rec["symbols"]:
@@ -667,7 +664,10 @@ def extend_and_specialize(
     return results
 
 
-def make_avro(i: List[Dict[str, Any]], loader: Loader,) -> List[Any]:
+def make_avro(
+    i: List[Dict[str, Any]],
+    loader: Loader,
+) -> List[Any]:
 
     j = extend_and_specialize(i, loader)
 
@@ -685,7 +685,10 @@ def make_avro(i: List[Dict[str, Any]], loader: Loader,) -> List[Any]:
     ]
 
 
-def make_avro_schema(i: List[Any], loader: Loader,) -> Names:
+def make_avro_schema(
+    i: List[Any],
+    loader: Loader,
+) -> Names:
     """
     All in one convenience function.
 
@@ -724,7 +727,7 @@ def print_inheritance(doc: List[Dict[str, Any]], stream: IO[Any]) -> None:
                     "\\l* ".join(shortname(field["name"]) for field in fields)
                 )
             shape = "ellipse" if entry.get("abstract") else "box"
-            stream.write('"{}" [shape={} label="{}"];\n'.format(name, shape, label))
+            stream.write(f'"{name}" [shape={shape} label="{label}"];\n')
             if "extends" in entry:
                 for target in aslist(entry["extends"]):
                     stream.write('"{}" -> "{}";\n'.format(shortname(target), name))
@@ -735,19 +738,17 @@ def print_fieldrefs(doc: List[Dict[str, Any]], loader: Loader, stream: IO[Any])
     """Write a GraphViz graph of the relationships between the fields."""
     obj = extend_and_specialize(doc, loader)
 
-    primitives = set(
-        (
-            "http://www.w3.org/2001/XMLSchema#string",
-            "http://www.w3.org/2001/XMLSchema#boolean",
-            "http://www.w3.org/2001/XMLSchema#int",
-            "http://www.w3.org/2001/XMLSchema#long",
-            saladp + "null",
-            saladp + "enum",
-            saladp + "array",
-            saladp + "record",
-            saladp + "Any",
-        )
-    )
+    primitives = {
+        "http://www.w3.org/2001/XMLSchema#string",
+        "http://www.w3.org/2001/XMLSchema#boolean",
+        "http://www.w3.org/2001/XMLSchema#int",
+        "http://www.w3.org/2001/XMLSchema#long",
+        saladp + "null",
+        saladp + "enum",
+        saladp + "array",
+        saladp + "record",
+        saladp + "Any",
+    }
 
     stream.write("digraph {\n")
     for entry in obj:
