@@ -1,4 +1,4 @@
-import pytest  # type: ignore
+import pytest
 
 import schema_salad
 import schema_salad.main
@@ -34,7 +34,10 @@ def test_errors() -> None:
         with pytest.raises(ValidationException):
             try:
                 load_and_validate(
-                    document_loader, avsc_names, path2, True,
+                    document_loader,
+                    avsc_names,
+                    path2,
+                    True,
                 )
             except ValidationException as e:
                 print("\n", e)
@@ -274,7 +277,7 @@ def test_error_message15() -> None:
         )
 
 
-@pytest.mark.skip(  # type: ignore
+@pytest.mark.skip(
     "See https://github.com/common-workflow-language/common-workflow-language/issues/734"  # noqa: B950
 )
 def test_errors_previously_defined_dict_key() -> None:
@@ -291,7 +294,10 @@ def test_errors_previously_defined_dict_key() -> None:
         with pytest.raises(ValidationException):
             try:
                 load_and_validate(
-                    document_loader, avsc_names, str(get_data("tests/" + t)), True,
+                    document_loader,
+                    avsc_names,
+                    str(get_data("tests/" + t)),
+                    True,
                 )
             except ValidationException as e:
                 print("\n", e)
