@@ -2,7 +2,7 @@ import os
 from typing import Optional
 from urllib.parse import urljoin, urlsplit
 
-import pytest  # type: ignore
+import pytest
 import requests
 
 from schema_salad.fetcher import Fetcher
@@ -12,7 +12,9 @@ from schema_salad.utils import CacheType
 
 class testFetcher(Fetcher):
     def __init__(
-        self, cache: CacheType, session: Optional[requests.sessions.Session],
+        self,
+        cache: CacheType,
+        session: Optional[requests.sessions.Session],
     ) -> None:
         pass
 
@@ -43,7 +45,9 @@ class testFetcher(Fetcher):
 
 class CWLTestFetcher(Fetcher):
     def __init__(
-        self, cache: CacheType, session: Optional[requests.sessions.Session],
+        self,
+        cache: CacheType,
+        session: Optional[requests.sessions.Session],
     ) -> None:
         pass
 
@@ -56,7 +60,7 @@ baseCommand: echo
 inputs: []
 outputs: []
 """
-        raise RuntimeError("Not foo.cwl, was %s" % url)
+        raise RuntimeError(f"Not foo.cwl, was {url}")
 
     def check_exists(self, url):  # type: (str) -> bool
         return url == "baz:bar/foo.cwl"
